@@ -347,7 +347,7 @@ function(x) {
 
   trix <- TRIX(xx,n=n,nSig=signal,maType=maType,percent=percent)
 
-  chobTA@TA.values <- trix[lchob@xsubset]
+  chobTA@TA.values <- trix[lchob@xsubset,]
 
   chobTA@name <- "chartTRIX"
   chobTA@call <- match.call()
@@ -947,8 +947,9 @@ function(x) {
   chobTA <- new("chobTA")
   chobTA@new <- TRUE
 
-  col <- if(missing(col)) col <- c('#999999','#777777',
-                              '#BBBBBB','#FF0000')
+  if(missing(col)) {
+    col <- c('#999999','#777777', '#BBBBBB','#FF0000')
+  }
 
   xx <- if(is.OHLC(x)) {
     Cl(x)
@@ -1037,7 +1038,7 @@ function(x) {
 
     x <- lchob@xdata
     i <- when
-    indexClass(x) <- "POSIXct"
+    tclass(x) <- "POSIXct"
     POSIXindex <- index(x)
     if (missing(i)) 
         i <- 1:NROW(x)
