@@ -1149,8 +1149,7 @@ function(Symbols,env,return.class='xts',
            warning("Oanda only provides historical data for the past 180 days.",
                    " Symbol: ", Symbols[[i]])
        }
-       oanda.URL <- paste0("https://www.oanda.com/fx-for-business/",
-                           "historical-rates/api/data/update/",
+       oanda.URL <- paste0("https://fxds-hcc.oanda.com/api/data/update",
                            "?&source=OANDA&adjustment=0",
                            "&base_currency=", currency.pair[1],
                            "&start_date=", from,
